@@ -1,5 +1,5 @@
 import os
-from latin.bglobals import *
+from bglobals import *
 
 
 
