@@ -1,4 +1,4 @@
-from latin.bglobals import *
+from bglobals import *
 
 
 def help():
